@@ -1,13 +1,13 @@
 #
-# $Id: H2Z.pm,v 0.99 2002/03/25 19:29:22 dankogai Exp dankogai $
+# $Id: H2Z.pm,v 1.0 2002/03/28 23:26:28 dankogai Exp dankogai $
 #
 
 package Encode::JP::H2Z;
 
 use strict;
 
-our $RCSID = q$Id: H2Z.pm,v 0.99 2002/03/25 19:29:22 dankogai Exp dankogai $;
-our $VERSION = do { my @r = (q$Revision: 0.99 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $RCSID = q$Id: H2Z.pm,v 1.0 2002/03/28 23:26:28 dankogai Exp dankogai $;
+our $VERSION = do { my @r = (q$Revision: 1.0 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use Carp;
 
@@ -165,3 +165,11 @@ sub z2h {
 }
 
 1;
+__END__
+
+
+=head1 NAME
+
+Encode::JP::H2Z -- internally used by Encode::JP::2022_JP*
+
+=cut
